#
# spec file for package kind
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kind
Version:        0.24.0
Release:        1.1
Summary:        Kubernetes IN Docker - local clusters for testing Kubernetes
License:        Apache-2.0
URL:            https://github.com/kubernetes-sigs/kind/
Source:         kind-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.16
Requires:       (docker or podman or nerdctl)

%description
kind is a tool for running local Kubernetes clusters using Docker container "nodes". kind was primarily designed for testing Kubernetes itself, but may be used for local development or CI.

If you have go 1.16+ and docker, podman or nerdctl installed go install sigs.k8s.io/kind@v0.22.0 && kind create cluster is all you need!

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags="-buildid= \
   -X sigs.k8s.io/kind/pkg/cmd/kind/version.gitCommit=$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo) \
   -X sigs.k8s.io/kind/pkg/cmd/kind/version.gitCommitCount=0" \
   -o bin/kind ./cmd/kind

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.24.0:
  * version v0.24.0
  * bump node image to 1.31.0
  * bump base image
  * bump kindnetd image
  * bump local path provisioner image
  * switch to go 1.22.6
  * Bump actions/upload-artifact from 4.3.5 to 4.3.6 in the actions
    group
  * Update copyright year in powershell.go
  * Add powershell completion
  * reword comments
  * Bump actions/upload-artifact from 4.3.4 to 4.3.5 in the actions
    group
  * bump kindnetd image
  * bump dependencies
  * Fix Kubeadm template format
  * Fix Ingress migration guide link error
  * Add known issue for WSL2 and cgroupv2 support
  * update rbac permissions for kindnet network policies
  * bump kindnetd image
  * implement network policies
  * use informers and context cancellation
  * kindnetd: update base image
  * Clean up known issues page
  * Mention possible pids_limit issues with rootless podman
  * Bump the actions group across 1 directory with 2 updates
  * bump node image
  * update base image
  * fix legacy env format warning
  * normalize FROM AS casing to silence buildx warnings
  * bump cni plugins to 1.5.1
  * update crictl to 1.30
  * update containerd to 1.7.18
  * update go / runc to go 1.22 / 1.1.13
  * Remove DOCKER_CLI_EXPERIMENTAL usage
  * simplify ingress guide, add Gateway API note
  * Add installation instructions for Scoop and Winget
  * switch to currently supported fedora (39)
  * Bump actions/checkout from 4.1.6 to 4.1.7 in the actions group
  * Add third party package installation note
  * e2e-k8s.sh: support --ginkgo.label-filter
  * Clean up GitHub Action definitions
  * cluster: drop DisableLocalStorageCapacityIsolation
  * switch to an active mirror
  * removed kong ingress documentation
  * Minor updates to Design docs
  * update comments regarding skipping preflight kubeadm phase
  * Add cgroupns requirement to known issues
  * update pause image to 3.10
  * Update Go dependencies
  * Add a new builder for tarballs and released artifacts
  * set skipPhases in Init and JoinConfiguration
  * Bump the actions group across 1 directory with 2 updates
  * promote stmcginnis to reviwer
  * update install docs for 0.23.0
  * version v0.24.0-alpha
  * Bump containerd to v1.7.16
  * group dependabot updates
  * make sure CI install the correct go
  * enable loading multiple image archives
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.23.0:
  This release introduces initial limited support for nerdctl and
  kube-proxy nftables mode.
  * Breaking Changes
  - The default node image is now Kubernetes 1.30.0:
    kindest/node:v1.30.0@sha256:047357ac0cfea04663786a612ba1eaba9702bef25227a794b52890dd8bcd692e
  - ipFamily config field is now validated
  - While technically a breaking change, if the value you set
    here is now caught as invalid it was being silently ignored
    and creating an ipv4 cluster previously and you should
    correct your config
  - Go 1.17+ is required for go install sigs.k8s.io/kind /
    building the kind binary
  - Prebuilt binaries are available as an alternative to go
    install
  - For local development make will automatically setup the
    correct go version
  - Note that the go team only supports 1.21+ and major linux
    distros have 1.19+
  - Future releases may increase this to a more current Go
    release
  - Future release may adopt toolchain in go.mod to make this
    seamless if you have go 1.21+ installed even without our
    makefile. We highly recommend installing go 1.21+
  * New Features
  - Initial support for nodes created with nerdctl
  - Initial support for kubeProxyMode: nftables (ahead of
    Kubernetes 1.31+, see
    https://kind.sigs.k8s.io/docs/user/configuration/#kube-proxy-mode)
  - Sweeping dependency updates, see commits for full details.
    v0.22.0...v0.23.0
* Mon Mar 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * version v0.22.0
  * update to 1.29.2 image
  * bump node image
  * drop creating /kind dir at node-image build time
  * bump base image
  * allow overriding IMAGE_NAME
  * update Contour ingress docs
* Mon Mar 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kind: Kubernetes IN Docker - local clusters for
  testing Kubernetes
